.. edam documentation master file, created by
sphinx-quickstart on Mon May 29 12:47:44 2017.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive.

Welcome to edam's documentation!
================================

.. toctree::
:maxdepth: 4
       :caption: Contents:

       edam


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
